==> iReport-1.2.0-src.zip: iReport-1.2.0-src/src/it/businesslogic/ireport/chart/BubblePlot.java <==
/*
 * PiePlot.java
 *
 * Created on 16 agosto 2005, 10.19
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class BubblePlot extends Plot{
    
    private String scaleType = "RangeAxis";
    
    private String xAxisLabelExpression = "";
    private String yAxisLabelExpression = "";
    
    /** Creates a new instance of PiePlot */
    public BubblePlot() {
    }
  
    public String getXAxisLabelExpression() {
        return xAxisLabelExpression;
    }

    public void setXAxisLabelExpression(String xAxisLabelExpression) {
        this.xAxisLabelExpression = xAxisLabelExpression;
    }

    public String getYAxisLabelExpression() {
        return yAxisLabelExpression;
    }

    public void setYAxisLabelExpression(String yAxisLabelExpression) {
        this.yAxisLabelExpression = yAxisLabelExpression;
    }

    public String getScaleType() {
        return scaleType;
    }

    public void setScaleType(String scaleType) {
        this.scaleType = scaleType;
    }
    
    public Plot cloneMe()
    {
        BubblePlot obj = new BubblePlot();
        copyBasePlot(obj);
        obj.setScaleType( this.getScaleType());
        obj.setYAxisLabelExpression( this.getYAxisLabelExpression());
        obj.setXAxisLabelExpression( this.getXAxisLabelExpression());
       
        return obj;
    }
    
}

==> iReport-1.2.7-src.zip: iReport-1.2.7-src/src/it/businesslogic/ireport/chart/BubblePlot.java <==
/*
 * PiePlot.java
 *
 * Created on 16 agosto 2005, 10.19
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class BubblePlot extends Plot{
    
    private String scaleType = "RangeAxis";
    
    private String xAxisLabelExpression = "";
    private String yAxisLabelExpression = "";
    
    private AxisFormat xAxisFormat = new AxisFormat();
    private AxisFormat yAxisFormat = new AxisFormat();
    
    /** Creates a new instance of PiePlot */
    public BubblePlot() {
    }
  
    public String getXAxisLabelExpression() {
        return xAxisLabelExpression;
    }

    public void setXAxisLabelExpression(String xAxisLabelExpression) {
        this.xAxisLabelExpression = xAxisLabelExpression;
    }

    public String getYAxisLabelExpression() {
        return yAxisLabelExpression;
    }

    public void setYAxisLabelExpression(String yAxisLabelExpression) {
        this.yAxisLabelExpression = yAxisLabelExpression;
    }

    public String getScaleType() {
        return scaleType;
    }

    public void setScaleType(String scaleType) {
        this.scaleType = scaleType;
    }
    
    public Plot cloneMe()
    {
        BubblePlot obj = new BubblePlot();
        copyBasePlot(obj);
        obj.setScaleType( this.getScaleType());
        obj.setYAxisLabelExpression( this.getYAxisLabelExpression());
        obj.setXAxisLabelExpression( this.getXAxisLabelExpression());
        
        obj.setXAxisFormat( getXAxisFormat().cloneMe());
        obj.setYAxisFormat( getYAxisFormat().cloneMe());
       
        return obj;
    }

    public AxisFormat getXAxisFormat() {
        return xAxisFormat;
    }

    public void setXAxisFormat(AxisFormat xAxisFormat) {
        this.xAxisFormat = xAxisFormat;
    }

    public AxisFormat getYAxisFormat() {
        return yAxisFormat;
    }

    public void setYAxisFormat(AxisFormat yAxisFormat) {
        this.yAxisFormat = yAxisFormat;
    }
    
}
